--- title: nbd_colab keywords: fastai sidebar: home_sidebar summary: "API details." ---

#### `drive_setup`[source]

> `drive_setup`()

Connect Google Drive to Colab instance

#### `change_dir`[source]

> `change_dir`(`path`)

Set the users home directory.

#### `clone_new_repo`[source]

> `clone_new_repo`()

Clone repo from github to google drive and configure

Function to clone a remote repo on github to creat a local repo at a specified destination on google drive.

The repo will be cloned to '/conten/drive/My Drive' by default.

After successful cloning, the local repo is automatically configured with users name, email, and password to allow automatic authentication for github integration. This requires the users github credentials (username and password) to be stored in the local repo on google drive (in the .git.config file). Sharing the local repo should therefore be avoided as this risks exposing your github authentication credentials to others.

Automatic notebook cleaning using nbdev_install_git_hooks is also activated to to ensure notebook metadata is sanitised to smooth github integration.

#### `setup_nb`[source]

> `setup_nb`(`repo`, `dir`=`None`)

Setup a new module notebook for use with nbdev